@@ -14,17 +14,11 @@
  * limitations under the License.
  */
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
- * @file grid_proxy_info.h
+ * @file grid_proxy_info.c
  * Globus GSI Proxy Utils
  * @author Sam Lang, Sam Meder
- *
- * $RCSfile: grid_proxy_info.c,v $
- * $Revision: 1.26 $
- * $Date: 2011/02/03 21:39:07 $
  */
-#endif
 
 #include "globus_common.h"
 #include "globus_error.h"
@@ -33,9 +27,6 @@
 #include "globus_gsi_proxy.h"
 #include "globus_gsi_credential.h"
 #include "globus_openssl.h"
-#ifdef WIN32
-#include "openssl/applink.c"
-#endif
 
 int                                     debug = 0;
 
